==> ml-pnet-0.7.0.tar.gz: ml-pnet-0.7.0/mcs-sources/class/System.Web/System.Web.UI/MasterPage.cs <==
//
// System.Web.UI.MasterPage.cs
//
// Authors:
//   Lluis Sanchez Gual (lluis@novell.com)
//
// (C) 2005 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;
using System.Collections;
using System.ComponentModel;
using System.Web.UI.WebControls;

namespace System.Web.UI
{
	public class MasterPage: UserControl
	{
		Hashtable templates = new Hashtable ();
		ArrayList placeholders = new ArrayList ();
		
		protected internal void AddContentTemplate (string templateName, ITemplate template)
		{
			templates [templateName] = template;
		}
		
		protected internal IList ContentPlaceHolders {
			get { return placeholders; }
		}
		
		protected internal ICollection ContentTemplates {
			get { return templates; }
		}
		
		internal void FillPlaceHolders ()
		{
			foreach (ContentPlaceHolder place in placeholders) {
				ITemplate template = templates [place.ID] as ITemplate;
				if (template != null)
					template.InstantiateIn (place);
			}
		}
	}
}

#endif

==> ml-pnet-0.7.4.tar.gz: ml-pnet-0.7.4/mcs-sources/class/System.Web/System.Web.UI/MasterPage.cs <==
//
// System.Web.UI.MasterPage.cs
//
// Authors:
//   Lluis Sanchez Gual (lluis@novell.com)
//
// (C) 2005 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;
using System.Collections;
using System.ComponentModel;
using System.Web.UI.WebControls;

namespace System.Web.UI
{
	public class MasterPage: UserControl
	{
		Hashtable templates = new Hashtable ();
		ArrayList placeholders = new ArrayList ();
		
		protected internal void AddContentTemplate (string templateName, ITemplate template)
		{
			templates [templateName] = template;
		}
		
		protected internal IList ContentPlaceHolders {
			get { return placeholders; }
		}
		
		protected internal ICollection ContentTemplates {
			get { return templates; }
		}
		
		internal void FillPlaceHolders ()
		{
			foreach (ContentPlaceHolder place in placeholders) {
				ITemplate template = templates [place.ID] as ITemplate;
				if (template != null) {
					place.Controls.Clear ();
					template.InstantiateIn (place);
				}
			}
		}
	}
}

#endif
